@@ -108,8 +108,8 @@ int arms_simple (int ninit, double *xl, double *xr,
 
 {
 double *xinit;
-xinit=(double *) malloc(ninit);
-  double convex=1.0, qcent, xcent;
+xinit= (double *)malloc(ninit*sizeof(double));
+double convex=1.0, qcent, xcent;
   int err, i, npoint=100, nsamp=1, ncent=0, neval; 
  
   /* set up starting values */
@@ -119,8 +119,8 @@ xinit=(double *) malloc(ninit);
 
   err = arms(xinit,ninit,xl,xr,myfunc,mydata,&convex,npoint,dometrop,xprev,xsamp,
              nsamp,&qcent,&xcent,ncent,&neval);
-free(xinit);
-  return err;
+  free(xinit);   
+return err;
 }
 
 /* *********************************************************************** */
